@@ -22,15 +22,14 @@
 
 #include "config.h"
 
-#include "i18n.h"
-
-
 #include "rgdummyinstallprogress.h"
-#include "gsynaptic.h"
+#include "rgmisc.h"
 
 #include <unistd.h>
 #include <stdio.h>
 
+#include "i18n.h"
+
 void RGDummyInstallProgress::startUpdate()
 {
     RGFlushInterface();
